@@ -1,14 +1,11 @@
 package PGObject::Simple::Role;
 
 use 5.010;
-
-use Carp::Clan qr/^PGObject\b/;
-use Log::Any qw($log);
-
+use strict;
+use warnings;
 use Moo::Role;
-# Anything imported after `use Moo::Role;` will be composed into consuming packages.
 use PGObject::Simple ':full', '!dbh';
-
+use Carp;
 
 =head1 NAME
 
@@ -16,19 +13,19 @@ PGObject::Simple::Role - Moo/Moose mappers for minimalist PGObject framework
 
 =head1 VERSION
 
-Version 2.1.1
+Version 2.0.1
 
 =cut
 
-our $VERSION = '2.1.1';
+our $VERSION = 2.000001;
 
 =head1 SYNOPSIS
 
-Take the following (Moo) class:
+Take the following (Moose) class:
 
     package MyAPP::Foo;
     use PGObject::Util::DBMethod;
-    use Moo;
+    use Moose;
     with 'PGObject::Simple::Role';
 
     has id  => (is => 'ro', isa => 'Int', required => 0);
@@ -36,7 +33,7 @@ Take the following (Moo) class:
     has bar => (is => 'ro', isa => 'Str', required => 0);
     has baz => (is => 'ro', isa => 'Int', required => 0);
 
-    sub _get_dbh {
+    sub get_dbh {
         return DBI->connect('dbi:Pg:dbname=foobar');
     }
     #  PGObject::Util::DBMethod exports this
@@ -75,34 +72,18 @@ declarative mapping.
 
 
 has _dbh => (  # use dbh() to get and set_dbh() to set
-       is => 'lazy',
-       isa => sub {
-           croak $log->error( "Expected a database handle.  Got $_[0] instead" )
-               unless eval {$_[0]->isa('DBI::db')};
-       },
-);
-
-has _DBH => ( # backwards compatible for 1.x.
-        is => 'lazy',
-       isa => sub {
-           warn $log->warn( 'deprecated _DBH used.  rename to _dbh when you can' );
-           croak $log->error( "Expected a database handle.  Got $_[0] instead" )
-               unless eval {$_[0]->isa('DBI::db')};
+       is => 'lazy', 
+       isa => sub { 
+                    croak "Expected a database handle.  Got $_[0] instead"
+                       unless eval {$_[0]->isa('DBI::db')};
        },
 );
 
 sub _build__dbh {
     my ($self) = @_;
-    return $self->{_DBH} if $self->{_DBH};
     return $self->_get_dbh;
 }
 
-sub _build__DBH {
-    my ($self) = @_;
-    return $self->{_dbh} if $self->{_dbh};
-    return $self->_dbh;
-}
-
 sub _get_dbh {
     croak 'Invoked _get_dbh from role improperly.  Subclasses MUST set this method';
 }
@@ -171,7 +152,7 @@ Wraps the PGObject::Simple method
 sub dbh {
     my ($self) = @_;
     if (ref $self){
-        return $self->_dbh;
+	return $self->_dbh;
     }
     return "$self"->_get_dbh;
 }
@@ -254,11 +235,19 @@ You can also look for information at:
 
 =item * RT: CPAN's request tracker (report bugs here)
 
-L<https://rt.cpan.org/NoAuth/Bugs.html?Dist=PGObject-Simple-Role>
+L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=PGObject-Simple-Role>
 
-=item * MetaCPAN
+=item * AnnoCPAN: Annotated CPAN documentation
 
-L<https://metacpan.org/dist/PGObject-Simple-Role>
+L<http://annocpan.org/dist/PGObject-Simple-Role>
+
+=item * CPAN Ratings
+
+L<http://cpanratings.perl.org/d/PGObject-Simple-Role>
+
+=item * Search CPAN
+
+L<http://search.cpan.org/dist/PGObject-Simple-Role/>
 
 =back
 
@@ -268,8 +257,7 @@ L<https://metacpan.org/dist/PGObject-Simple-Role>
 
 =head1 LICENSE AND COPYRIGHT
 
-  Copyright 2013-2017 Chris Travers
-  Copyright 2016-2021 The LedgerSMB Core team
+Copyright 2013-2017 Chris Travers,.
 
 Redistribution and use in source and compiled forms with or without 
 modification, are permitted provided that the following conditions are met:
